@@ -5,9 +5,9 @@ cwd = os.getcwd()
 print(cwd)
 
 file_path_in = os.path.join(cwd, "excel2sbol", 'tests', 'test_files',
-                            'personalpaper.xlsx')
+                            'SBOL3_simple_library4.xlsx')
 file_path_out = os.path.join(cwd, "excel2sbol", 'tests', 'test_files',
-                             'personalpaper.xml')
+                             'SBOL3_simple_library4.nt')
 
 conv.converter(file_path_in, file_path_out)
 # conv.converter(file_path_in, file_path_out, sbol_version=2,
